@@ -1,15 +1,17 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2012 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
 import errno
 import os
@@ -38,7 +40,7 @@ class xdg(object):
     def save_config_path(xdg, resource):
         path = os.path.join(xdg.xdg_config_home, resource)
         try:
-            os.makedirs(path, 0700)
+            os.makedirs(path, 0o700)
         except OSError:
             if not os.path.isdir(path):
                 raise
@@ -58,7 +60,9 @@ class Config(object):
         self._data = {}
         self._resource = resource
         for directory in xdg.load_config_paths(resource):
-            self._load(os.path.join(directory, '%s.conf' % resource))
+            self._load(
+                os.path.join(directory, '{res}.conf'.format(res=resource))
+            )
         self._legacy_path = legacy_path
         if legacy_path is not None:
             self._load(legacy_path)
@@ -88,7 +92,7 @@ class Config(object):
     def _load(self, path):
         try:
             file = open(path, 'r')
-        except IOError, ex:
+        except IOError as ex:
             if ex.errno == errno.ENOENT:
                 return
         try:
@@ -107,14 +111,14 @@ class Config(object):
         if not self._dirty:
             return
         directory = xdg.save_config_path(self._resource)
-        path = os.path.join(directory, '%s.conf' % self._resource)
+        path = os.path.join(directory, '{res}.conf'.format(res=self._resource))
         tmp_path = path + '.tmp'
         file = open(tmp_path, 'w')
         try:
             for key, value in sorted(self._data.iteritems()):
                 if isinstance(value, unicode):
                     value = value.encode('UTF-8')
-                file.write('%s=%s\n' % (key, value))
+                file.write('{key}={val}\n'.format(key=key, val=value))
             file.flush()
             os.fsync(file.fileno())
         finally:
@@ -130,9 +134,9 @@ class Config(object):
         if self._legacy_path is not None:
             try:
                 os.remove(self._legacy_path)
-            except OSError, ex:
+            except OSError as ex:
                 if ex.errno != errno.ENOENT:
                     raise
         self._dirty = False
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
