@@ -1,15 +1,17 @@
 # encoding=UTF-8
 
-# Copyright © 2008-2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
 import os.path
 import subprocess
@@ -63,17 +65,17 @@ class temporary_file(object):
 
 class Editor(object):
 
-    def __call__(self, file_name):
+    def __call__(self, path):
         raise NotImplementedError
 
 class RunMailcapEditor(object):
 
-    def __call__(self, file_name):
-        file_name = os.path.abspath(file_name)
+    def __call__(self, path):
+        path = os.path.abspath(path)
         edit = subprocess.Popen(
-            ['edit', 'text/plain:%s' % file_name],
-            stdin = subprocess.PIPE,
-            stdout = subprocess.PIPE,
+            ['edit', 'text/plain:{path}'.format(path=path)],
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
         )
         edit.stdin.close()
         edit.stdout.close()
@@ -85,15 +87,15 @@ class CustomEditor(object):
         self._command = [command]
         self._command += extra_args
 
-    def __call__(self, file_name):
-        file_name = os.path.abspath(file_name)
+    def __call__(self, path):
+        path = os.path.abspath(path)
         edit = subprocess.Popen(
-            self._command + [file_name],
-            stdin = subprocess.PIPE,
-            stdout = subprocess.PIPE,
+            self._command + [path],
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
         )
         edit.stdin.close()
         edit.stdout.close()
         edit.wait()
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
