@@ -3,14 +3,16 @@
 # Copyright © 2008-2014 Jakub Wilk <jwilk@jwilk.net>
 # Copyright © 2009 Mateusz Turcza <mturcza@mimuw.edu.pl>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
 import wx
 
@@ -42,7 +44,7 @@ class OutlineCallback(models.outline.OutlineCallback):
 
 class OutlineBrowser(wx.TreeCtrl):
 
-    def __init__(self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.DefaultSize, style = wx.TR_HAS_BUTTONS | wx.TR_EDIT_LABELS):
+    def __init__(self, parent, id=wx.ID_ANY, pos=wx.DefaultPosition, size=wx.DefaultSize, style=(wx.TR_HAS_BUTTONS | wx.TR_EDIT_LABELS)):
         wx.TreeCtrl.__init__(self, parent, id, pos, size, style)
         self._items = {}
         self._root_item = None
@@ -101,11 +103,11 @@ class OutlineBrowser(wx.TreeCtrl):
             try:
                 n = int(buffer(uri, 1))
             except ValueError:
-                return # TODO: try to handle non-local URIs
+                return  # TODO: try to handle non-local URIs
             parent = wx.GetTopLevelParent(self)
             parent.page_no = n - 1
         else:
-            return # TODO: try to handle non-local URIs
+            return  # TODO: try to handle non-local URIs
 
     def do_delete_node(self, node):
         try:
@@ -268,4 +270,4 @@ class OutlineBrowser(wx.TreeCtrl):
 
 __all__ = ['OutlineBrowser']
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
