@@ -2,14 +2,16 @@
 
 # Copyright © 2008-2014 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
 import wx
 import wx.lib.ogl
@@ -53,7 +55,7 @@ class Zoom(object):
 
 class PercentZoom(Zoom):
 
-    def __init__(self, percent = 100):
+    def __init__(self, percent=100):
         self._percent = float(percent)
 
     def rezoom_on_resize(self):
@@ -101,7 +103,7 @@ class FitPageZoom(Zoom):
         return True
 
     def get_page_screen_size(self, page_job, (viewport_width, viewport_height)):
-        real_width, real_height  = (page_job.width, page_job.height)
+        real_width, real_height = (page_job.width, page_job.height)
         ratio = 1.0 * real_height / real_width
         screen_height = int(viewport_width * ratio)
         if screen_height <= viewport_height:
@@ -244,7 +246,7 @@ class NodeShape(wx.lib.ogl.RectangleShape):
         self._update_size()
         self._update_text()
         canvas = self.GetCanvas()
-        canvas.Refresh() # FIXME: something lighter here?
+        canvas.Refresh()  # FIXME: something lighter here?
 
     def _update_node_size(self):
         x, y, w, h = self.GetX(), self.GetY(), self.GetWidth(), self.GetHeight()
@@ -261,7 +263,7 @@ class NodeShape(wx.lib.ogl.RectangleShape):
         canvas.PrepareDC(dc)
         return canvas, dc
 
-    def deselect(self, notify = True, cdc = None):
+    def deselect(self, notify=True, cdc=None):
         if not self.Selected():
             return
         try:
@@ -273,7 +275,7 @@ class NodeShape(wx.lib.ogl.RectangleShape):
         if notify:
             self.node.notify_deselect()
 
-    def select(self, notify = True, cdc = None):
+    def select(self, notify=True, cdc=None):
         if self.Selected():
             return
         try:
@@ -317,13 +319,12 @@ class PageTextCallback(models.text.PageTextCallback):
 
 class TextShape(NodeShape):
 
-    _FRAME_COLORS = \
-    {
-        djvu.const.TEXT_ZONE_COLUMN:    (0x80, 0x80, 0x00),
-        djvu.const.TEXT_ZONE_REGION:    (0x80, 0x80, 0x80),
+    _FRAME_COLORS = {
+        djvu.const.TEXT_ZONE_COLUMN: (0x80, 0x80, 0x00),
+        djvu.const.TEXT_ZONE_REGION: (0x80, 0x80, 0x80),
         djvu.const.TEXT_ZONE_PARAGRAPH: (0x80, 0x00, 0x00),
-        djvu.const.TEXT_ZONE_LINE:      (0x80, 0x00, 0x80),
-        djvu.const.TEXT_ZONE_WORD:      (0x00, 0x00, 0x80),
+        djvu.const.TEXT_ZONE_LINE: (0x80, 0x00, 0x80),
+        djvu.const.TEXT_ZONE_WORD: (0x00, 0x00, 0x80),
         djvu.const.TEXT_ZONE_CHARACTER: (0x00, 0x80, 0x00),
     }
 
@@ -384,9 +385,9 @@ class ShapeEventHandler(wx.lib.ogl.ShapeEvtHandler):
         dc = wx.ClientDC(canvas)
         canvas.PrepareDC(dc)
         if shape.Selected():
-            shape.deselect(notify = True)
+            shape.deselect(notify=True)
         else:
-            shape.select(notify = True)
+            shape.select(notify=True)
 
     def OnRightClick(self, x, y, keys=0, attachment=0):
         shape = self.GetShape()
@@ -394,12 +395,11 @@ class ShapeEventHandler(wx.lib.ogl.ShapeEvtHandler):
 
 class PageWidget(wx.lib.ogl.ShapeCanvas):
 
-    _WXK_TO_LINK_GETTER = \
-    {
-        wx.WXK_LEFT:  lambda node: node.left_sibling,
+    _WXK_TO_LINK_GETTER = {
+        wx.WXK_LEFT: lambda node: node.left_sibling,
         wx.WXK_RIGHT: lambda node: node.right_sibling,
-        wx.WXK_UP:    lambda node: node.parent,
-        wx.WXK_DOWN:  lambda node: node.left_child
+        wx.WXK_UP: lambda node: node.parent,
+        wx.WXK_DOWN: lambda node: node.left_child
     }
 
     def __init__(self, parent):
@@ -487,11 +487,11 @@ class PageWidget(wx.lib.ogl.ShapeCanvas):
         # TODO: something lighter
 
     def _on_shape_selected(self, shape):
-        shape.select(notify = False) # in case it was selected otherwhere
+        shape.select(notify=False)  # in case it was selected elsewhere
         self._current_shape = shape
 
     def _on_shape_deselected(self, shape):
-        shape.deselect(notify = False) # in case it was selected otherwhere
+        shape.deselect(notify=False)  # in case it was selected elsewhere
         self._current_shape = None
 
     def on_parent_resize(self, event):
@@ -588,18 +588,18 @@ class PageWidget(wx.lib.ogl.ShapeCanvas):
                 self._image = None
             if page_job is not None:
                 image = PageImage(self,
-                    page_job = page_job,
-                    real_page_size = real_page_size,
-                    viewport_size = viewport_size,
-                    screen_page_size = screen_page_size,
-                    xform_real_to_screen = xform_real_to_screen,
-                    render_mode = self.render_mode,
-                    zoom = self.zoom)
+                    page_job=page_job,
+                    real_page_size=real_page_size,
+                    viewport_size=viewport_size,
+                    screen_page_size=screen_page_size,
+                    xform_real_to_screen=xform_real_to_screen,
+                    render_mode=self.render_mode,
+                    zoom=self.zoom)
                 image.SetDraggable(False, False)
                 self._image = image
             self.setup_nonraster_shapes()
             self.recreate_shapes()
-        return property(fset = set)
+        return property(fset=set)
 
     def recreate_shapes(self):
         self.remove_all_shapes()
@@ -643,11 +643,10 @@ class PageWidget(wx.lib.ogl.ShapeCanvas):
         self._nonraster_shapes = ()
         self._nonraster_shapes_map = {}
 
-    def setup_maparea_shapes(self, have_text = False):
+    def setup_maparea_shapes(self, have_text=False):
         xform_real_to_screen = self._xform_real_to_screen
         try:
-            items = \
-            [
+            items = [
                 (node, MapareaShape(node, have_text, xform_real_to_screen))
                 for node in self._page_annotations.mapareas
             ]
@@ -656,12 +655,11 @@ class PageWidget(wx.lib.ogl.ShapeCanvas):
         except decode.NotAvailable:
             pass
 
-    def setup_text_shapes(self, have_text = False):
+    def setup_text_shapes(self, have_text=False):
         xform_text_to_screen = self._xform_text_to_screen
         try:
             page_type = sexpr.Symbol('page')
-            items = \
-            [
+            items = [
                 (node, TextShape(node, have_text, xform_text_to_screen))
                 for node in self._page_text.get_preorder_nodes()
                 if node is not None and node.type < djvu.const.TEXT_ZONE_PAGE
@@ -677,4 +675,4 @@ __all__ = [
     'RENDER_NONRASTER_TEXT', 'RENDER_NONRASTER_MAPAREA'
 ]
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
