@@ -1,15 +1,17 @@
 # encoding=UTF-8
 
-# Copyright © 2008-2010 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
 '''
 Models for annotations.
@@ -215,10 +217,10 @@ class MapArea(Annotation):
         self = cls(
             *cls.DEFAULT_ARGUMENTS,
             **dict(
-                uri = uri,
-                target = target,
-                comment = comment,
-                owner = owner
+                uri=uri,
+                target=target,
+                comment=comment,
+                owner=owner
             )
         )
         if maparea is None:
@@ -251,7 +253,7 @@ class MapArea(Annotation):
             shape_iter = iter(shape)
             cls = MAPAREA_SHAPE_TO_CLASS[shape_iter.next().value]
             args = [int(item) for item in shape_iter]
-            kwargs = dict(uri = uri, target = target, comment = comment, owner = owner)
+            kwargs = dict(uri=uri, target=target, comment=comment, owner=owner)
             for item in sexpr:
                 try:
                     key, value = item
@@ -262,7 +264,7 @@ class MapArea(Annotation):
                     key = key.value
                     value = True
                 kwargs['s_%s' % key] = value
-        except (StopIteration, TypeError), ex:
+        except (StopIteration, TypeError) as ex:
             raise MapAreaSyntaxError(ex)
         return cls(*args, **kwargs)
 
@@ -320,7 +322,7 @@ class MapArea(Annotation):
             self._border = SolidBorder(parse_color(options.pop('s_%s' % djvu.const.MAPAREA_BORDER_SOLID_COLOR)))
         except KeyError:
             pass
-        except (TypeError, ValueError), ex:
+        except (TypeError, ValueError) as ex:
             raise MapAreaSyntaxError(ex)
 
     def _parse_shadow_border_options(self, options):
@@ -329,7 +331,7 @@ class MapArea(Annotation):
                 width = self._parse_width(options.pop('s_%s' % border_style))
             except KeyError:
                 continue
-            except (TypeError, ValueError), ex:
+            except (TypeError, ValueError) as ex:
                 raise MapAreaSyntaxError(ex)
             cls = MAPAREA_SHADOW_BORDER_TO_CLASS[border_style]
             self._border = cls(width)
@@ -509,7 +511,7 @@ class RectangleMapArea(XywhMapArea):
             self._highlight_color = parse_color(options.pop('s_%s' % djvu.const.MAPAREA_HIGHLIGHT_COLOR))
         except KeyError:
             self._highlight_color = None
-        except (TypeError, ValueError), ex:
+        except (TypeError, ValueError) as ex:
             raise MapAreaSyntaxError(ex)
         try:
             self._opacity = int(options.pop('s_%s' % djvu.const.MAPAREA_OPACITY))
@@ -517,7 +519,7 @@ class RectangleMapArea(XywhMapArea):
                 raise MapAreaSyntaxError
         except KeyError:
             self._opacity = djvu.const.MAPAREA_OPACITY_DEFAULT
-        except (TypeError, ValueError), ex:
+        except (TypeError, ValueError) as ex:
             raise MapAreaSyntaxError(ex)
         self._parse_common_options(options)
         self._check_invalid_options(options)
@@ -583,14 +585,20 @@ class PolygonMapArea(MapArea):
         x0 = y0 = 1e999
         x1 = y1 = -1e999
         for (x, y) in self._coords:
-            if x < x0: x0 = x
-            if y < y0: y0 = y
-            if x > x1: x1 = x
-            if y > y1: y1 = y
+            if x < x0:
+                x0 = x
+            if y < y0:
+                y0 = y
+            if x > x1:
+                x1 = x
+            if y > y1:
+                y1 = y
         w = x1 - x0
         h = y1 - y0
-        if w <= 0: w = 1
-        if h <= 0: h = 1
+        if w <= 0:
+            w = 1
+        if h <= 0:
+            h = 1
         return (x0, y0, w, h)
 
     def _set_rect(self, rect):
@@ -691,13 +699,13 @@ class LineMapArea(MapArea):
                 raise ValueError
         except KeyError:
             self._line_width = djvu.const.MAPAREA_LINE_MIN_WIDTH
-        except (TypeError, ValueError), ex:
+        except (TypeError, ValueError) as ex:
             raise MapAreaSyntaxError(ex)
         try:
             self._line_color = parse_color(options.pop('s_%s' % djvu.const.MAPAREA_LINE_COLOR))
         except KeyError:
             self._line_color = djvu.const.MAPAREA_LINE_COLOR_DEFAULT
-        except (TypeError, ValueError), ex:
+        except (TypeError, ValueError) as ex:
             raise MapAreaSyntaxError(ex)
         self._parse_border_options(options)
         self._parse_common_options(options)
@@ -735,7 +743,7 @@ class LineMapArea(MapArea):
         def get(self):
             return NotImplemented
         def set(self, value):
-            pass # FIXME?
+            pass  # FIXME?
         return property(get, set)
 
 class TextMapArea(XywhMapArea):
@@ -755,20 +763,20 @@ class TextMapArea(XywhMapArea):
         self._parse_xywh(x, y, w, h)
         self._parse_border_options(options)
         self._parse_border_always_visible(options)
-            # XXX Reference (8.3.4.2.3.1 Miscellaneous parameters) states that ``(border_avis)``
-            # is not relevant for text annotations. Nevertheless that option can be found
-            # in the wild, e.g. in the ``lizard2005-antz.djvu`` file.
+        # XXX Reference (8.3.4.2.3.1 Miscellaneous parameters) states that ``(border_avis)``
+        # is not relevant for text annotations. Nevertheless that option can be found
+        # in the wild, e.g. in the ``lizard2005-antz.djvu`` file.
         try:
             self._background_color = parse_color(options.pop('s_%s' % djvu.const.MAPAREA_BACKGROUND_COLOR))
         except KeyError:
             self._background_color = None
-        except (TypeError, ValueError), ex:
+        except (TypeError, ValueError) as ex:
             raise MapAreaSyntaxError(ex)
         try:
             self._text_color = parse_color(options.pop('s_%s' % djvu.const.MAPAREA_TEXT_COLOR))
         except KeyError:
             self._text_color = djvu.const.MAPAREA_TEXT_COLOR_DEFAULT
-        except (TypeError, ValueError), ex:
+        except (TypeError, ValueError) as ex:
             raise MapAreaSyntaxError(ex)
         try:
             del options['s_%s' % djvu.const.MAPAREA_PUSHPIN]
@@ -826,8 +834,7 @@ MAPAREA_SHAPE_TO_CLASS = dict(
     for cls in (RectangleMapArea, OvalMapArea, PolygonMapArea, LineMapArea, TextMapArea)
 )
 
-ANNOTATION_TYPE_TO_CLASS = \
-{
+ANNOTATION_TYPE_TO_CLASS = {
     djvu.const.ANNOTATION_MAPAREA: MapArea
 }
 
@@ -914,14 +921,16 @@ class PageAnnotations(object):
             callback.notify_node_delete(node)
 
     def notify_node_select(self, node):
-        for callback in self._callbacks: callback.notify_node_select(node)
+        for callback in self._callbacks:
+            callback.notify_node_select(node)
 
     def notify_node_deselect(self, node):
-        for callback in self._callbacks: callback.notify_node_deselect(node)
+        for callback in self._callbacks:
+            callback.notify_node_deselect(node)
 
 class SharedAnnotations(object):
 
     def export_select(self, djvused):
         djvused.create_shared_annotations()
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
