@@ -2,14 +2,16 @@
 
 # Copyright © 2008-2012 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
 '''
 Models for document outline.
@@ -188,10 +190,10 @@ class InnerNode(Node):
         stream.write('    ' * indent)
         stream.write(self.uri)
         stream.write(' ')
-        stream.write(self.text.encode('UTF-8')) # TODO: what about control characters etc.?
+        stream.write(self.text.encode('UTF-8'))  # TODO: what about control characters etc.?
         stream.write('\n')
         for child in self:
-            child.export_as_plaintext(stream, indent = indent + 1)
+            child.export_as_plaintext(stream, indent=(indent + 1))
 
     def delete(self):
         try:
@@ -300,4 +302,4 @@ class Outline(object):
         tree[0:1] = djvu.const.EMPTY_OUTLINE
         self.raw_value = djvu.sexpr.Expression(tree)
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
