@@ -1,15 +1,17 @@
 # encoding=UTF-8
 
-# Copyright © 2008-2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
 class Operation(object):
 
@@ -20,23 +22,33 @@ class Operation(object):
         return cmp(self.cost, other.cost)
 
     def __repr__(self):
-        return '%s(cost=%r)' % (self.__class__.__name__, self.cost)
+        return '{cls}(cost={cost})'.format(
+            cls=type(self).__name__,
+            cost=self.cost
+        )
 
     def __add__(self, other):
         return self.cost + other
 
-class Delete(Operation): pass
-class Insert(Operation): pass
-class Substitute(Operation): pass
-class Drop(Operation): pass
-class Append(Operation): pass
+class Delete(Operation):
+    pass
+class Insert(Operation):
+    pass
+class Substitute(Operation):
+    pass
+class Drop(Operation):
+    pass
+class Append(Operation):
+    pass
 
 def distance(s, t):
     len_s = len(s)
     len_t = len(t)
     d = [[None for j in xrange(len_t + 1)] for i in xrange(len_s + 1)]
-    for i in xrange(len_s + 1): d[i][0] = Drop(i)
-    for j in xrange(len_t + 1): d[0][j] = Append(j)
+    for i in xrange(len_s + 1):
+        d[i][0] = Drop(i)
+    for j in xrange(len_t + 1):
+        d[0][j] = Append(j)
     for i in xrange(1, len_s + 1):
         for j in xrange(1, len_t + 1):
             subst_cost = int(s[i-1] != t[j-1])
@@ -71,4 +83,4 @@ def distance(s, t):
 
 __all__ = ['distance']
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
