@@ -1,15 +1,17 @@
 # encoding=UTF-8
 
-# Copyright © 2008-2009 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
 import re
 import functools
@@ -38,9 +40,9 @@ def not_overridden(f):
     def new_f(self, *args, **kwargs):
         cls = type(self)
         warnings.warn(
-            '`%s.%s.%s()` is not overridden' % (cls.__module__, cls.__name__, f.__name__),
-            category = NotOverriddenWarning,
-            stacklevel = 2
+            '`{mod}.{cls}.{func}()` is not overridden'.format(mod=cls.__module__, cls=cls.__name__, func=f.__name__),
+            category=NotOverriddenWarning,
+            stacklevel=2
         )
         return f(self, *args, **kwargs)
     return new_f
@@ -100,11 +102,10 @@ def indents_to_tree(lines):
         memo += (indent, current),
     return root
 
-URI_SPECIAL_CHARACTERS = \
-(
-    ':/?#[]@' +    # RFC 3986, `gen-delims`
-    '!$&()*+,;=' + # RFC 3986, `sub-delims`
-    '%'            # RFC 3986, `pct-encoded`
+URI_SPECIAL_CHARACTERS = (
+    ':/?#[]@' +  # RFC 3986, `gen-delims`
+    '!$&()*+,;=' +  # RFC 3986, `sub-delims`
+    '%'  # RFC 3986, `pct-encoded`
 )
 
 def fix_uri(s):
@@ -168,11 +169,10 @@ class idict(object):
         self.__dict__.update(kwargs)
 
     def __repr__(self):
-        return '%s.%s(%s)' % \
-        (
-            self.__module__,
-            self.__class__.__name__,
-            ', '.join('%s=%r' % (k, v) for k, v in self.__dict__.iteritems())
+        return '{mod}.{cls}({init})'.format(
+            mod=self.__module__,
+            cls=type(self).__name__,
+            init=', '.join('{k}={v!r}'.format(k=k, v=v) for k, v in self.__dict__.iteritems())
         )
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
